@@ -34,6 +34,17 @@
 	#undef _CRYPT_RIJNDAEL_H_TYPES
 #endif
 
+/* Irix. We could include stdint.h and use uint8_t but that also
+ * requires that we specifically drive the compiler in C99 mode.
+ * Defining UINT8 as unsigned char is, ultimately, what stdint.h
+ * would do anyway.
+ */
+#if defined(_SGIAPI)
+    #define _CRYPT_RIJNDAEL_H_TYPES
+    typedef __uint32_t  UINT32;
+    typedef unsigned char UINT8;
+#endif
+
 /* Solaris has sys/types.h, but doesn't act like everyone else 
  * GCC defines __sun__ and __sun (report from Todd Ross)
  * Solaris cc defines __sun
@@ -44,6 +55,22 @@
 	typedef uint8_t  UINT8;
 #endif
 
+/* Mac OS X 10.3 defines things differently than most other 
+systems */
+#if defined( __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ ) &&  __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__-0 < 1140
+	#define _CRYPT_RIJNDAEL_H_TYPES
+	typedef u_int32_t UINT32;
+	typedef u_char    UINT8;
+#endif
+
+/* Mac OS X 10.3 defines things differently than most other
+systems */
+#if defined(__APPLE__) && ! defined(__DARWIN_UNIX03)
+	#define _CRYPT_RIJNDAEL_H_TYPES
+	typedef u_int32_t UINT32;
+	typedef u_char  UINT8;
+#endif
+
 /* I expect this to be the usual case */
 #if ! defined(_CRYPT_RIJNDAEL_H_TYPES) && ( defined(_SYS_TYPES_H) || defined(_SYS_TYPES_H_) )   
 	#define _CRYPT_RIJNDAEL_H_TYPES
